import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, HostBinding, HostListener, Directive, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class DisclosureComponent {
    constructor() {
        this.panelChange = new EventEmitter();
        this._isOpen = false;
    }
    get isOpened() {
        return this._isOpen;
    }
    set isOpened(hidden) {
        if (this._isOpen === hidden) {
            return;
        }
        this._isOpen = hidden;
    }
    ngOnChanges() {
        this._isOpen = !!this.defaultOpenState;
    }
    addPanel(panel) {
        this.displayPanel = panel;
        this.panelChange.emit(panel.hidden);
    }
    addButton(button) {
        this.disclosureButton = button;
    }
    keyNavActions() {
        this.displayPanel.hidden = !this.displayPanel.hidden;
        this.updateOpenState();
    }
    updateOpenState() {
        this.isOpened = !this._isOpen;
        this.panelChange.emit(this.isOpened);
    }
}
DisclosureComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosureComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
DisclosureComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: DisclosureComponent, selector: "headless-disclosure", inputs: { defaultOpenState: "defaultOpenState", disabled: "disabled" }, outputs: { panelChange: "panelChange" }, host: { properties: { "class.opened-headless-disclosure": "this.isOpened" } }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosureComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'headless-disclosure',
                    template: `<ng-content></ng-content>`,
                }]
        }], propDecorators: { defaultOpenState: [{
                type: Input
            }], disabled: [{
                type: Input
            }], panelChange: [{
                type: Output
            }], isOpened: [{
                type: HostBinding,
                args: ['class.opened-headless-disclosure']
            }] } });

class DisclosureButtonComponent {
    constructor(disclosureParent) {
        this._disabled = false;
        this.cursorType = 'pointer';
        this.disclosure = disclosureParent;
        this.disclosure.addButton(this);
    }
    get disabled() {
        return this._disabled;
    }
    set disabled(disabled) {
        if (this._disabled === disabled) {
            return;
        }
        this._disabled = disabled;
    }
    ngOnInit() {
        if (this.disclosure.disabled) {
            this.disabled = true;
        }
        else {
            this.disabled = false;
        }
    }
    onClick() {
        if (this.disabled)
            return;
        this.disclosure.keyNavActions();
    }
}
DisclosureButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosureButtonComponent, deps: [{ token: DisclosureComponent }], target: i0.ɵɵFactoryTarget.Component });
DisclosureButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: DisclosureButtonComponent, selector: "headless-disclosure-button", host: { listeners: { "mousedown": "onClick($event)" }, properties: { "style.cursor": "this.cursorType", "class.disabled": "this.disabled" } }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosureButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'headless-disclosure-button',
                    template: `<ng-content></ng-content>`,
                }]
        }], ctorParameters: function () { return [{ type: DisclosureComponent }]; }, propDecorators: { cursorType: [{
                type: HostBinding,
                args: ['style.cursor']
            }], disabled: [{
                type: HostBinding,
                args: ['class.disabled']
            }], onClick: [{
                type: HostListener,
                args: ['mousedown', ['$event']]
            }] } });

class DisclosurePanelDirective {
    constructor(disclosureParent) {
        this._hidden = false;
        this.disclosure = disclosureParent;
        this.disclosure.addPanel(this);
    }
    get hidden() {
        return this._hidden;
    }
    set hidden(hidden) {
        if (this._hidden === hidden) {
            return;
        }
        this._hidden = hidden;
    }
    ngOnInit() {
        if (this.disclosure.defaultOpenState) {
            this.hidden = false;
        }
        else {
            this.hidden = true;
        }
    }
}
DisclosurePanelDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosurePanelDirective, deps: [{ token: DisclosureComponent }], target: i0.ɵɵFactoryTarget.Directive });
DisclosurePanelDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.1.1", type: DisclosurePanelDirective, selector: "headlessDisclosurePanel, [headlessDisclosurePanel]", host: { properties: { "class.hidden": "this.hidden" } }, exportAs: ["headlessDisclosurePanel"], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DisclosurePanelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'headlessDisclosurePanel, [headlessDisclosurePanel]',
                    exportAs: 'headlessDisclosurePanel'
                }]
        }], ctorParameters: function () { return [{ type: DisclosureComponent }]; }, propDecorators: { hidden: [{
                type: HostBinding,
                args: ['class.hidden']
            }] } });

class UiDisclosureModule {
}
UiDisclosureModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: UiDisclosureModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
UiDisclosureModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: UiDisclosureModule, declarations: [DisclosureComponent,
        DisclosureButtonComponent,
        DisclosurePanelDirective], imports: [CommonModule], exports: [DisclosureComponent,
        DisclosureButtonComponent,
        DisclosurePanelDirective] });
UiDisclosureModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: UiDisclosureModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: UiDisclosureModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [
                        DisclosureComponent,
                        DisclosureButtonComponent,
                        DisclosurePanelDirective
                    ],
                    exports: [
                        DisclosureComponent,
                        DisclosureButtonComponent,
                        DisclosurePanelDirective
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DisclosureButtonComponent, DisclosureComponent, DisclosurePanelDirective, UiDisclosureModule };
//# sourceMappingURL=ngheadlessui-disclosure.mjs.map
